//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[HanHuOptions](index.md)

# HanHuOptions

[common]\
@Serializable

data class [HanHuOptions](index.md)(val aotenjou: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, val hasKiriageMangan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, val hasKazoeYakuman: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true)

## Constructors

| | |
|---|---|
| [HanHuOptions](-han-hu-options.md) | [common]<br>constructor(aotenjou: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, hasKiriageMangan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, hasKazoeYakuman: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true) |

## Types

| Name | Summary |
|---|---|
| [Companion](-companion/index.md) | [common]<br>object [Companion](-companion/index.md) |

## Properties

| Name | Summary |
|---|---|
| [aotenjou](aotenjou.md) | [common]<br>val [aotenjou](aotenjou.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false<br>是否为青天井规则 |
| [hasKazoeYakuman](has-kazoe-yakuman.md) | [common]<br>val [hasKazoeYakuman](has-kazoe-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true<br>是否有累计役满 |
| [hasKiriageMangan](has-kiriage-mangan.md) | [common]<br>val [hasKiriageMangan](has-kiriage-mangan.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false<br>是否有切上满贯 |
